local libFrameRecycle = ...

if not Library then Library = {} end
local libFrameRecycle = {}
if not Library.libFrameRecycle then Library.libFrameRecycle = libFrameRecycle end

local LFR = {}
LFR.contexts = {}
LFR.frames = {}
LFR.unusedFrames = {}
LFR.usedFrames = {}

function libFrameRecycle.getContext(name)
	if name == nil then
		name = "LFR"
	end
	if LFR.contexts[name] == nil then
		LFR.contexts[name] = UI.CreateContext(name)
	end
	return LFR.contexts[name]
end

function libFrameRecycle.getRoot()
	if next(LFR.contexts) then
		return next(LFR.contexts)
	end
	error("No available context")
end

function libFrameRecycle.getFrame(type, name, parent)
	if parent == nil then
		parent = getRoot()
	end
	if next(LFR.unusedFrames) == nil then
		f = libFrameRecycle.createFrame(type, name, parent)
		f.used = true
		LFR.usedFrames[f.id] = f
		LFR.unusedFrames[f.id] = nil
		return f
	end
	for k,v in pairs(LFR.unusedFrames) do
		return libFrameRecycle.recycleFrame(v)
	end
end

function libFrameRecycle.recycleFrame(frame)
	frame.used = true
	LFR.usedFrames[frame.id] = frame
	LFR.unusedFrames[f.id] = nil
	return frame
end

function libFrameRecycle.createFrame(type, name, parent)
	f = UI.CreateFrame(type, name, parent)
	f.id = name .. "_" .. Inspect.Time.Server()
	f.used = false
	LFR.frames[f.id] = f
	LFR.unusedFrames[f.id] = f
	return f
end

function libFrameRecycle.unuseFrame(frame)
	frame.used = false
	LFR.usedFrames[f.id] = nil
	LFR.unusedFrames[f.id] = f
end